@@ -1,5 +1,5 @@
 package Schedule::LongSteps;
-$Schedule::LongSteps::VERSION = '0.012';
+$Schedule::LongSteps::VERSION = '0.013';
 # ABSTRACT: Manage long term processes over arbitrary large spans of time.
 
 use Moose;
@@ -16,6 +16,13 @@ An example of such a process would be: "After an order has been started, if more
 
 Such a process is usually a pain to implement and this is an attempt to provide a framework so it would make writing and testing such a process as easy as writing and testing a good old Class.
 
+=head1 INCOMPATIBLE CHANGES
+
+From 0.013
+
+The API of Storage has changed between 0.012 and 0.013. If you've written your own storage, you
+will want to manage that. If not, then don't worry about it.
+
 =head1 CONCEPTS
 
 =head2 Process
@@ -364,9 +371,9 @@ sub run_due_processes{
     my ($self, $context) = @_;
     $context ||= {};
 
-    my $stored_processes = $self->storage->prepare_due_processes();
+    my @stored_processes = $self->storage->prepare_due_processes();
     my $process_count = 0;
-    while( my $stored_process = $stored_processes->next() ){
+    foreach  my $stored_process ( @stored_processes ){
         my $process_method = $stored_process->what();
 
         $process_count++;
