@@ -1,12 +1,11 @@
 package Schedule::LongSteps::Storage::Memory;
-$Schedule::LongSteps::Storage::Memory::VERSION = '0.012';
+$Schedule::LongSteps::Storage::Memory::VERSION = '0.013';
 use Moose;
 extends qw/Schedule::LongSteps::Storage/;
 
 use DateTime;
 
 use Log::Any qw/$log/;
-use MooseX::Iterator;
 
 =head1 NAME
 
@@ -51,7 +50,7 @@ sub prepare_due_processes{
             push @to_run , $process;
         }
     }
-    return  MooseX::Iterator::Array->new( collection => \@to_run );
+    return @to_run;
 }
 
 =head2 find_process
@@ -85,7 +84,7 @@ sub create_process{
 __PACKAGE__->meta->make_immutable();
 
 package Schedule::LongSteps::Storage::Memory::Process;
-$Schedule::LongSteps::Storage::Memory::Process::VERSION = '0.012';
+$Schedule::LongSteps::Storage::Memory::Process::VERSION = '0.013';
 use Moose;
 
 use DateTime;
